/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

#include <QtDeclarative>
#include "hooks.h"
#include "anchor.h"

/*!
    \class LoginHook
    \brief Le hook LoginHook gère le transfert des données de login du socket
    vers l'ancre, située entre la partie graphique et logique de l'application.
*/

class LoginHook : public AccountHook
{
public:

    /*!
        \fn LoginHook::LoginHook()
        \brief Constructeur de la classe.

        Construit un objet LoginHook.

        Appelle également AccountHook() pour enregistrer le hook dans la liste des
        hooks de type \a HOOK_TYPE_ACCOUNT.
    */

    LoginHook() : AccountHook() { }

    /*!
        \fn LoginHook::onLoginAccepted()
        \brief Appelle la fonction loginSuccess() de l'ancre.
    */

    void onLoginAccepted() {
        ANCHOR->loginSuccess();
    }

    /*!
        \fn LoginHook::onLoginRefused()
        \brief Appelle la fonction loginFailure() de l'ancre.
    */

    void onLoginRefused() {
        ANCHOR->loginFailure();
    }
};

/*!
    \fn HookMgr::addAccountHooks()
    \brief Instancie les hooks de type \a HOOK_TYPE_ACCOUNT.
*/

void HookMgr::addAccountHooks()
{
    new LoginHook;
}
