/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

#ifndef TCPSOCKET_H
#define TCPSOCKET_H

#include <QtGui>
#include <QtNetwork>

#define CLIENT_USERNAME "developpez.com"
#define CLIENT_PASSWORD "developpez"

class TcpSocket : public QTcpSocket
{
    Q_OBJECT

public:
    explicit TcpSocket();
    void unhandled(QDataStream*);
    void handlePong(QDataStream*);
    void handleLogin(QDataStream*);
    void handleMedicineModel(QDataStream*);
    void handlePatientsModel(QDataStream*);
    void handleBodyPartsModel(QDataStream*);
    void handlePatientQuery(QDataStream*);
    void handleNewPatient(QDataStream*);
    void handleModifyPatient(QDataStream*);
    void handleNewDiagnostic(QDataStream*);
    void handleNewSymptom(QDataStream*);
    void handleRemovePrescription(QDataStream*);
    void handleModifyPrescription(QDataStream*);
    void handleNewPrescription(QDataStream*);
    void handleEnterChat(QDataStream*);
    void handleLeaveChat(QDataStream*);
    void handleChatMessage(QDataStream*);
    void handleChatUsersRequest(QDataStream*);
    void handleEcgData(QDataStream*);
    void handleAnalysisModel(QDataStream*);
    void handleScanRequest(QDataStream*);
    void handleRadioRequest(QDataStream*);

    void sendLogin(QString, QString);
    void sendRequestForMedicineModel();
    void sendRequestForPatients();
    void sendRequestForBodyParts();
    void sendRequestForPatient(int);
    void sendPatientInfos(int, QStringList);
    void sendNewDiagnostic(int, QString);
    void sendNewSymptom(int, QString);
    void sendRemovePrescription(int, int);
    void sendPrescription(int, int, QString, int, int);
    void sendEnterChat();
    void sendLeaveChat();
    void sendMessageInChat(QString);
    void sendChatUsersRequest();
    void sendStartECG(int);
    void sendStopECG();
    void sendRequestForAnalysis();
    void sendRequestForScan(int, int);
    void sendRequestForRadio(int, int, int);

private slots:
    void read();
    void sendPing();
    void reconnect();
    void handleConnected();

private:
    void handleMessage(QDataStream*);
    void sendEmptyMessage(int);
    /*! Utilisé pour envoyer des pings. */
    QTimer _pingTimer;
    /*! Utilisé pour calculer la latence. */
    QTime _pongTime;
    /*! La taille du paquet reçu. */
    quint64 _size;
    /*! Le nombre de tentatives de reconnexions. */
    int _reconnectTries;
};

#endif // TCPSOCKET_H
