/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

#include "mainwindow.h"
#include "hooks.h"
#include "tcpsocket.h"
#include "anchor.h"
#include "qmlapplicationviewer.h"

/*!
    \class MainWindow
    \brief La classe MainWindow est la classe correspondant à la fenêtre.

    La classe MainWindow, en plus d'afficher la fenêtre principale de
    l'application, sert à lancer le TcpSocket \a _socket puis à l'initialiser
    afin de le préparer à l'utilisation.
*/

/*!
    \fn MainWindow::MainWindow()
    \brief Crée et initialise le socket.
*/

MainWindow::MainWindow() : _socket(NULL), _anchor(new Anchor)
{
    _viewer = new QmlApplicationViewer;
    _viewer->setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
    _viewer->rootContext()->setContextProperty("anchor", _anchor);
    _viewer->setMainQmlFile(QLatin1String("qml/main.qml"));
    _viewer->setMinimumSize(650, 400);
    _viewer->setMaximumSize(800, 600);
    _viewer->setWindowTitle("Utopital");
    _viewer->setWindowIcon(QIcon(":/images/icon.png"));
    _viewer->setWindowFlags(Qt::FramelessWindowHint);
    _viewer->move(QApplication::desktop()->availableGeometry(_viewer).width() / 2
        - _viewer->frameSize().width() / 2, QApplication::desktop()
        ->availableGeometry(_viewer).height() / 2
        - _viewer->frameSize().height() / 2);
    _viewer->show();
}

/*!
    \fn MainWindow::initialize()
    \brief Initialiseur de la classe.

    Initialise le système de hooks, puis le socket et enfin l'ancre entre
    l'interface graphique et la partie logique de l'application.
*/

void MainWindow::initialize()
{
    hookMgr.initialize(_anchor);
    _socket = new TcpSocket;
    _anchor->setSocket(_socket);
}

/*!
    \fn MainWindow::~MainWindow()
    \brief Destructeur de la classe.
*/

MainWindow::~MainWindow()
{
    hookMgr.freeInstance();
    _socket->abort();
    delete _socket;
}
