/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

import QtQuick 1.0

ToolBar {

    default property alias content: stack.children
    property bool popupInfosVisible: false

    id: bottomBar
    anchors.bottom: parent.bottom
    anchors.left: parent.left
    anchors.right: parent.right
    height: btnInfos.height + 10

    MouseArea {
        anchors.fill: parent
    }

    LittlePopup {
        id: infosPopup
        radius: 5; smooth: true
        width: infosArea.width + 15
        height: infosArea.height + 15

        CommonText {
            id: infosArea
            anchors.centerIn: parent
            verticalAlignment: Text.AlignVCenter
            color: "#000000"
            font.bold: false
            style: Text.Normal
            text: "Latence : " + anchor.latency + " ms<br />"
                + "État de la connexion : " + ((anchor.latency < 100)
                ? "excellente" : (anchor.latency < 1000)
                ? "bonne" : "mauvaise")
                + "<br />Nom d'utilisateur : " + anchor.username
                + "<br />Niveau d'utilisateur : administrateur"
        }

        Image {
            parent: infosPopup
            source: "qrc:/images/arrow.png"
            width: 23; height: 13
            anchors.top: parent.bottom
            anchors.left: parent.left
            anchors.leftMargin: - infosPopup.x + btnInfos.x
                + Math.round(btnInfos.width/2) - 10
        }

        Behavior on opacity { NumberAnimation { duration: 500 } }

        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.rightMargin: 5
        anchors.bottomMargin: bottomBar.height + 8
        visible: popupInfosVisible
        opacity: visible ? 1 : 0
        onHideRequest: popupInfosVisible = false
    }

    Icon {
        id: btnIcon
        anchors.left: parent.left
        anchors.verticalCenter: parent.verticalCenter
        anchors.leftMargin: 10
    }

    Item {
        id: stack
        anchors.left: btnIcon.right
        anchors.right: btnInfos.left
        anchors.top: parent.top
        anchors.bottom: parent.bottom
    }

    Button {
        id: btnInfos
        text: "Infos"
        border.color: "#424242"
        anchors.right: btnClose.left
        anchors.rightMargin: 10
        anchors.verticalCenter: parent.verticalCenter
        onClicked: popupInfosVisible = true
    }

    Button {
        id: btnClose
        text: "Quitter"
        anchors.right: parent.right
        anchors.rightMargin: 10
        anchors.verticalCenter: parent.verticalCenter
        border.color: "#424242"
        onClicked: Qt.quit();
    }
}
