/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

import QtQuick 1.0
import "../Gradients"

Rectangle {

    property alias text: textInput.text
    property bool hoverEnabled: true
    property alias textInput: textInput
    property int heightExtra: 16
    property int widthExtra: 32

    signal clicked()
    signal pressed()
    signal released()
    signal entered()
    signal exited()

    radius: 4
    smooth: true
    border.width: 1
    width: textInput.width + widthExtra
    height: textInput.height + heightExtra
    opacity: !enabled ? 0.3 : mouseArea.pressed || mouseArea.containsMouse ? 0.7 : 1
    gradient: BlackGradient { }

    Behavior on opacity { NumberAnimation { duration: 100 } }

    CommonText {
        id: textInput
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
    }

    MouseArea {
        id: mouseArea
        anchors.fill: parent
        enabled: parent.enabled
        hoverEnabled: parent.hoverEnabled
        onClicked: parent.clicked()
        onPressed: parent.pressed()
        onReleased: parent.released()
        onEntered: parent.entered()
        onExited: parent.exited()
    }
}
