/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

import Qt 4.7

Item {
    property color currentColor: "#FF0000"
    property color selectedColor: "#FFFFFF"

    function extractRGB() {
        var color = String(currentColor).replace("#", "");
        var array = new Array();
        var regExp = new RegExp("(..)", "g");
        color.replace(regExp, function(color) {
            array.push(parseInt(color, 16));
        });
        return array;
    }

    function extractHSB(r, g, b) {
        var _h = 0;
        var minValue = Math.min(r, g, b);
        var maxValue = Math.max(r, g, b);
        var maxDelta = maxValue - minValue;
        if (maxDelta != 0) {
            var redDelta = (((maxValue - r) / 6) + (maxDelta / 2)) / maxDelta;
            var greenDelta = (((maxValue - g) / 6) + (maxDelta / 2)) / maxDelta;
            var blueDelta = (((maxValue - b) / 6) + (maxDelta / 2)) / maxDelta;
            _h = (r == maxValue) ? (blueDelta - greenDelta)
                : (g == maxValue) ? ((1 / 3) + redDelta - blueDelta)
                : (b == maxValue) ? ((2 / 3) + greenDelta - redDelta) : 0;
            _h = (_h < 0) ? _h + 1 : (_h > 1) ? _h - 1 : _h;
        }
        var _s = cursor.x / picker.width;
        var _b = 0.5 - (cursor.y / picker.height) / 2;
        return new Array(_h, _s, _b);
    }

    function extractHSL() {
        var rgb = picker.extractRGB();
        var hsb = picker.extractHSB(rgb[0], rgb[1], rgb[2]);
        var _h = hsb[0];
        var _l = (2 - hsb[1]) * hsb[2];
        var _s = hsb[1] * hsb[2] / ((_l <= 1) ? _l : 2 - _l);
        return new Array(_h, _s, _l);
    }

    function setColor() {
        var hsl = extractHSL();
        selectedColor = Qt.hsla(hsl[0], hsl[1], hsl[2], 1);
    }

    onCurrentColorChanged: {
        setColor();
    }

    id: picker
    clip: true

    Rectangle {
        anchors.fill: parent;
        rotation: 90
        gradient: Gradient {
            GradientStop { position: 0.0; color: picker.currentColor }
            GradientStop { position: 1.0; color: "#ffffff" }
        }
    }

    Rectangle {
        anchors.fill: parent
        gradient: Gradient {
            GradientStop { position: 0.0; color: "transparent" }
            GradientStop { position: 1.0; color: "#ff000000" }
        }
    }

    Item {
        id: cursor
        width: 6
        height: 6

        Rectangle {
            width: parent.width * 2
            height: parent.height * 2
            anchors.centerIn: parent
            radius: parent.width
            border.color: "#c4c4c4"
            border.width: 1
            smooth: true

            gradient: Gradient {
                GradientStop { position: 0.0; color: "#ffffff" }
                GradientStop { position: 1.0; color: "#cccccc" }
            }
        }
    }

    MouseArea {
        anchors.fill: parent
        onPressed: {
            cursor.x = Math.max(0, Math.min(width, mouse.x));
            cursor.y = Math.max(0, Math.min(height, mouse.y));
            picker.setColor();
        }
        onPositionChanged: {
            cursor.x = Math.max(0, Math.min(width, mouse.x));
            cursor.y = Math.max(0, Math.min(height, mouse.y));
            picker.setColor();
        }
    }
}
