/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

import QtQuick 1.0

Rectangle {
    property string title: ""
    property bool closable: true
    default property alias content: stack.children

    signal hideRequest()

    id: popup
    color: "#f8000000"
    z: 2; clip: true
    radius: 6; smooth: true

    MouseArea {
        anchors.fill: parent
    }

    Rectangle {
        id: titleArea
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top
        anchors.topMargin: -10
        anchors.leftMargin: 10
        anchors.rightMargin: 10
        height: 45; color: "#885F5F5F"
        border.width: 1; border.color: "#424242"
        radius: 6; smooth: true

        Button {
            text: "Fermer"
            visible: popup.closable
            textInput { font.pixelSize: 14 }
            widthExtra: 34
            height: 25
            border.color: "#424242"
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 5
            anchors.rightMargin: 10
            radius: Math.floor(height/2)
            onClicked: popup.hideRequest()
        }

        CommonText {
            text: parent.parent.title
            font.pixelSize: 18
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 5
            anchors.horizontalCenter: parent.horizontalCenter
        }
    }

    Item {
        id: stack
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: titleArea.bottom
        anchors.bottom: parent.bottom
        anchors.margins: 10
    }
}
