/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

import QtQuick 1.0

import QtQuick 1.0
import "../Gradients"

Rectangle {
    GreenGradient { id: greenGradient }
    BlueGradient { id: blueGradient }

    FontLoader {
        id: textFont
        source: "qrc:/font/Rom_Ftl_Srif_Std_Juan_Casco.TTF"
    }

    property alias textInput: input
    property alias text: input.text
    signal editingFinished()

    gradient: input.activeFocus ? blueGradient : greenGradient
    radius: 3
    smooth: true

    Rectangle {
        id: content
        anchors.fill: parent
        anchors.margins: 2
        radius: 2
        color: "#ffffff"
        smooth: true

        Flickable {
            id: flickable
            anchors.fill: parent
            contentWidth: width
            contentHeight: Math.max(height, input.height)
            clip: true

            function ensureVisible(r)
            {
                if (contentX >= r.x)
                    contentX = r.x;
                else if (contentX + width <= r.x + r.width)
                    contentX = r.x + r.width - width;
                if (contentY >= r.y)
                    contentY = r.y;
                else if (contentY + height <= r.y + r.height)
                    contentY = r.y + r.height - height;
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if (!input.focus)
                        input.focus = true;
                }
            }

            Behavior on contentY { SpringAnimation { spring: 2; damping: 0.2 } }

            TextEdit {
                id: input
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                opacity: enabled ? 1 : 0.5
                selectByMouse: true
                smooth: true
                color: "#000000"
                font.bold: true
                font.family: textFont.name
                font.pointSize: 12
                font.italic: false
                wrapMode: TextEdit.Wrap
                onCursorRectangleChanged: {
                    flickable.ensureVisible(cursorRectangle);
                }
                onTextChanged: {
                    if (flickable.contentHeight > flickable.height)
                        flickable.contentY = flickable.contentHeight - flickable.height;
                }
            }
        }
    }
}
