/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

import QtQuick 1.0
import "../Components"

Rectangle {
    border.width: 1; border.color: "grey"
    width: medicineSelector.width - 2
    height: medicineSelector.currentIndex != index
        ? 35 : nameArea.height + descriptionArea.height + 20
    color: medicineSelector.currentIndex != index
        ? "#c85F5F5F" : "#888888"

    CommonText {
        id: nameArea
        verticalAlignment: Text.AlignVCenter
        anchors.left: parent.left
        anchors.right: selectedBox.left
        anchors.top: parent.top
        anchors.leftMargin: 15
        anchors.topMargin: 5
        anchors.rightMargin: 15
        height: 25; text: name
        elide: Text.ElideRight
        font.underline: medicineSelector.currentIndex == index
    }

    CommonText {
        id: descriptionArea
        anchors.top: nameArea.bottom
        anchors.left: nameArea.left
        anchors.right: nameArea.right
        anchors.topMargin: 5
        wrapMode: Text.Wrap
        text: level + " - " + description
        font.pointSize: 11
        visible: medicineSelector.currentIndex == index
        opacity: visible ? 1 : 0
        Behavior on opacity { NumberAnimation { duration: 500 } }
    }

    CheckBox {
        id: selectedBox
        anchors.right: parent.right
        anchors.verticalCenter: parent.verticalCenter
        anchors.rightMargin: 15
        checked: true; autoSwitchState: false
        opacity: medicineSelector.currentIndex != index ? 0 : 1
        Behavior on opacity { NumberAnimation { duration: 1000 } }
    }

    MouseArea {
        anchors.fill: parent
        onClicked: {
            medicineSelector.currentIndex = index;
            medicineSelector.positionViewAtIndex(index, ListView.Center);
        }
    }
}
