/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

import QtQuick 1.0
import "Components"
import "Popups"

Rectangle {

    property bool waitingForAnswer: false
    property bool loginSuccessed: false
    property bool popupLoginResultVisible: false

    id: login
    anchors.fill: parent
    color: "#545454"

    Background { }

    Button {
        text: "X"
        textInput { font.pixelSize: 10 }
        widthExtra: 10
        heightExtra: 10
        border.color: "#424242"
        anchors.right: parent.right
        anchors.top: parent.top
        anchors.topMargin: 10
        anchors.rightMargin: 10
        onClicked: Qt.quit();
    }

    WaitPopup {
        visible: parent.waitingForAnswer
        text: "Tentative d'authentification...\n\nVeuillez patienter."
    }

    PopupAuthentificate {
        visible: popupLoginResultVisible
        opacity: visible ? 1 : 0
    }

    Column {
        id: loginArea
        anchors.centerIn: parent
        spacing: 16
        Item {
            anchors.horizontalCenter: parent.horizontalCenter
            height: loginImage.height + 40
            width: parent.width
            Image {
                id: loginImage
                anchors.top: parent.top
                anchors.horizontalCenter: parent.horizontalCenter
                source: "qrc:/images/password.png"
            }
        }
        Column {
            spacing: 8
            CommonText { text: "Login :" }
            CommonTextInput {
                id: loginField
                textInput { text: "Jean Dupont" }
                width: 200; height: 30
                onEditingFinished: {
                    loginArea.enabled = false;
                    anchor.login(loginField.textInput.text,
                        passwordField.textInput.text);
                }
            }
        }
        Column {
            spacing: 8
            CommonText { text: "Mot de passe :" }
            CommonTextInput {
                id: passwordField
                textInput {
                    text: "motdepasse"
                    echoMode: TextInput.Password
                }
                width: 200; height: 30
                onEditingFinished: {
                    loginArea.enabled = false;
                    anchor.login(loginField.textInput.text,
                        passwordField.textInput.text);
                }
            }
        }
        Button {
            text: "Connexion"
            anchors.horizontalCenter: parent.horizontalCenter
            onClicked: {
                loginArea.enabled = false;
                anchor.login(loginField.textInput.text,
                    passwordField.textInput.text);
            }
        }
    }

    Connections {
        target: anchor
        onLoginSuccess: {
            loginSuccessed = true;
            waitingForAnswer = false;
            popupLoginResultVisible = true;
            anchor.username = loginField.textInput.text;
        }
        onLoginFailure: {
            loginSuccessed = false;
            waitingForAnswer = false;
            popupLoginResultVisible = true;
        }
    }
}
