/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

import QtQuick 1.0
import "Components"
import "Delegates"
import "Gradients"
import "Popups"

Rectangle {
    id: module
    anchors.fill: parent
    color: "#545454"

    property alias chatTextArea: chatArea

    onVisibleChanged: {
        if (!visible) {
            anchor.leaveChat();
            main.userInChat = false;
            content.flipped = false;
        }
    }

    Background { }

    MenuAccessor { }

    Menus {
        id: menusArea
        contentHeight: content.height
    }

    FlipableFrame {
        id: content
        anchors.top: parent.top
        anchors.left: menusArea.right
        anchors.bottom: bottomBar.top
        width: parent.width

        front: Button {
            anchors.centerIn: parent
            text: "Entrer dans le salon !"
            onClicked: {
                anchor.enterChat();
                main.userInChat = true;
                content.flipped = true;
            }
        }

        back: Item {
            anchors.fill: parent

            Item {
                id: leftArea
                anchors.left: parent.left
                anchors.top: parent.top
                anchors.bottom: parent.bottom
                anchors.leftMargin: 10
                width: 175

                Rectangle {
                    id: leftAreaTitle
                    anchors.top: parent.top
                    anchors.left: parent.left
                    anchors.right: parent.right
                    anchors.topMargin: -10
                    height: 45; color: "#5F5F5F"
                    border.width: 1; border.color: "grey"
                    radius: 6; smooth: true

                    CommonText {
                        anchors.bottom: parent.bottom
                        anchors.left: parent.left
                        anchors.right: parent.right
                        anchors.bottomMargin: 10
                        horizontalAlignment: Text.AlignHCenter
                        text: "Comptes connectés"
                    }
                }

                Rectangle {
                    id: leftAreaContent
                    anchors.top: leftAreaTitle.bottom
                    anchors.left: parent.left
                    anchors.right: parent.right
                    anchors.bottom: parent.bottom
                    anchors.bottomMargin: -bottomBar.height - 10
                    anchors.topMargin: 10; radius: 6
                    color: "#5F5F5F"; smooth: true
                    border.width: 1; border.color: "grey"

                    ListView {
                        id: salonConnectedView
                        anchors.top: parent.top
                        anchors.left: parent.left
                        anchors.right: parent.right
                        anchors.bottom: parent.bottom
                        anchors.topMargin: 20
                        anchors.bottomMargin: bottomBar.height + 10
                        model: chatUsers; clip: true
                        delegate: SalonConnectedListDelegate { }
                    }
                }
            }

            Rectangle {
                id: topRightArea
                anchors.left: leftArea.right
                anchors.right: parent.right
                anchors.top: parent.top
                anchors.leftMargin: 11
                anchors.rightMargin: 10
                anchors.topMargin: -10
                height: 65; color: "#5F5F5F"
                border.width: 1; border.color: "grey"
                radius: 6; smooth: true
                visible: patientInfos.count == 1

                CommonText {
                    id: nameArea
                    anchors.left: parent.left
                    anchors.right: parent.right
                    anchors.bottom: parent.bottom
                    anchors.leftMargin: 10
                    anchors.bottomMargin: 15
                    anchors.rightMargin: 10
                    height: 25; elide: Text.ElideRight
                    verticalAlignment: Text.AlignVCenter
                    text: "Vous êtes :<br />" + anchor.username
                }
            }

            Rectangle {
                clip: true
                anchors.top: topRightArea.bottom
                anchors.left: topRightArea.left
                anchors.right: topRightArea.right
                anchors.bottom: parent.bottom
                anchors.bottomMargin: -bottomBar.height - 10
                anchors.topMargin: 10; color: "#5F5F5F"
                border.width: 1; border.color: "grey"

                ScrollableTextEdit {
                    id: chatArea
                    anchors.left: parent.left
                    anchors.right: parent.right
                    anchors.top: parent.top
                    anchors.bottom: messageArea.top
                    anchors.margins: 10
                    textInput {
                        anchors.leftMargin: 2
                        anchors.rightMargin: 2
                        readOnly: true
                        textFormat: Text.PlainText
                        font.pointSize: 11
                    }
                }

                CommonTextInput {
                    id: messageArea
                    anchors.left: parent.left
                    anchors.right: buttonSend.left
                    anchors.bottom: parent.bottom
                    anchors.bottomMargin: bottomBar.height + 20
                    anchors.leftMargin: 10
                    anchors.rightMargin: 10
                    height: 25
                    onEditingFinished: {
                        if (text != "") {
                            anchor.sendMessageInChat(text);
                            text = "";
                        }
                    }
                }

                Button {
                    id: buttonSend
                    text: "Envoyer !"
                    anchors.right: parent.right
                    anchors.bottom: messageArea.bottom
                    anchors.top: messageArea.top
                    anchors.rightMargin: 10
                    onClicked: {
                        if (messageArea.text != "") {
                            anchor.sendMessageInChat(messageArea.text);
                            messageArea.text = "";
                        }
                    }
                }
            }
        }
    }

    BottomBar {
        id: bottomBar
    }
}
