/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

import QtQuick 1.0
import "../Components"

MouseArea {

    signal hideRequest(bool accepted, string name,
        string birthyear, bool man, string address,
        bool alive, bool canGoHome, bool urgencied);

    // Si patientId < 0, la popup gère l'ajout d'un patient
    // Sinon, modification du patient actuel.
    property int patientId: -1
    property bool popupInfosVisible: false

    // "private"
    signal finished(bool accepted)

    onFinished: {
        if (accepted) {
            if (nameField.text == "") {
                popupInfosVisible = true;
                popupInfos.text = "Vous devez donner le nom du patient.";
                return;
            }
            else if (birthyearField.text > new Date().getFullYear()) {
                popupInfosVisible = true;
                popupInfos.text = "Vous devez donner une année de naissance valide.";
                return;
            }
            else if (addressField.text == "") {
                popupInfosVisible = true;
                popupInfos.text = "Vous devez donner l'adresse du patient.";
                return;
            }
        }
        popup.hideRequest(accepted, nameField.text, birthyearField.text,
            genderM.checked, addressField.text, aliveCheckBox.checked,
            canGoHomeCheckBox.checked, urgenciedCheckBox.checked);
    }

    onVisibleChanged: {
        if (visible) {
            var patient = patientInfos.get(0);
            var currentDate = new Date();

            if (patient && patientId != -1) {
                nameField.text = patient.name;
                birthyearField.text = parseInt(currentDate.getFullYear() - patient.age);
                genderM.checked = patient.gender == 0;
                genderF.checked = patient.gender == 1;
                addressField.text = patient.address;
                aliveCheckBox.checked = patient.isDead == 0;
                canGoHomeCheckBox.checked = patient.canGoHome == 1;
                urgenciedCheckBox.checked = patient.urgencied == 1;
            }
            else {
                nameField.text = "";
                birthyearField.text = currentDate.getFullYear();
                genderM.checked = true;
                genderF.checked = false;
                addressField.text = "";
                aliveCheckBox.checked = true;
                canGoHomeCheckBox.checked = false;
                urgenciedCheckBox.checked = false;
            }
        }
    }

    id: popup
    anchors.fill: parent; z: 2
    hoverEnabled: true

    PopupInformation {
        id: popupInfos
        visible: popupInfosVisible
        opacity: visible ? 1 : 0
        title: "Erreur"; z: 4
        onHideRequest: popupInfosVisible = false;
    }

    Rectangle {
        anchors.fill: parent
        color: "#000000"
        opacity: 0.7
    }

    ComplexPopup {
        width: 550
        height: 255
        anchors.centerIn: parent
        anchors.verticalCenterOffset: - Math.floor(bottomBar.height/2)
        onHideRequest: finished(false);
        opacity: parent.visible ? 1 : 0
        title: !patientsModel.get(patientId) ?
            "Ajout d'un patient"
            : ("Dossier de " + patientsModel.get(patientId).name)

        Behavior on opacity { NumberAnimation { duration: 250 } }

        Column {
            id: contentArea
            anchors.top: parent.top
            anchors.topMargin: 10
            width: parent.width
            height: childrenRect.height
            spacing: 10

            Item {
                width: parent.width
                height: 30

                CommonText {
                    id: nameLabel
                    text: "Nom :"
                    anchors.left: parent.left
                    anchors.verticalCenter: parent.verticalCenter
                }
                CommonTextInput {
                    id: nameField
                    height: 25
                    anchors.left: nameLabel.right
                    anchors.right: parent.right
                    anchors.leftMargin: 10
                    anchors.verticalCenter: parent.verticalCenter
                    textInput { validator: regex }
                }
            }

            Item {
                width: parent.width
                height: 30

                CommonText {
                    id: birthyearLabel
                    text: "Année de naissance :"
                    anchors.verticalCenter: parent.verticalCenter
                }
                CommonTextInput {
                    id: birthyearField
                    height: 25
                    anchors.left: birthyearLabel.right
                    anchors.right: genderLabel.left
                    anchors.leftMargin: 10
                    anchors.rightMargin: 10
                    anchors.verticalCenter: parent.verticalCenter
                    textInput { validator: IntValidator { bottom: 0; top: 3000 } }
                }
                CommonText {
                    id: genderLabel
                    text: "Sexe :"
                    anchors.right: genderM.left
                    anchors.rightMargin: 10
                    anchors.verticalCenter: parent.verticalCenter
                }
                CheckBox {
                    id: genderM
                    checked: true
                    autoSwitchState: false
                    anchors.right: genderMLabel.left
                    anchors.rightMargin: 10
                    anchors.verticalCenter: parent.verticalCenter
                    onToggle: {
                        checked = check;
                        genderF.checked = !check;
                    }
                }
                CommonText {
                    id: genderMLabel
                    text: "Homme"
                    anchors.right: genderF.left
                    anchors.rightMargin: 10
                    anchors.verticalCenter: parent.verticalCenter
                }
                CheckBox {
                    id: genderF
                    checked: false
                    autoSwitchState: false
                    anchors.right: genderFLabel.left
                    anchors.rightMargin: 10
                    anchors.verticalCenter: parent.verticalCenter
                    onToggle: {
                        checked = check;
                        genderM.checked = !check;
                    }
                }
                CommonText {
                    id: genderFLabel
                    text: "Femme"
                    anchors.right: parent.right
                    anchors.verticalCenter: parent.verticalCenter
                }
            }

            Item {
                width: parent.width
                height: 30

                CommonText {
                    id: addressLabel
                    text: "Adresse :"
                    anchors.verticalCenter: parent.verticalCenter
                }
                CommonTextInput {
                    id: addressField
                    height: 25
                    anchors.left: addressLabel.right
                    anchors.right: parent.right
                    anchors.leftMargin: 10
                    anchors.verticalCenter: parent.verticalCenter
                    textInput { validator: regex }
                }
            }

            Row {
                spacing: 10

                CommonText {
                    text: "Statut :"
                    anchors.verticalCenter: parent.verticalCenter
                }
                CheckBox {
                    id: aliveCheckBox
                    checked: true
                    anchors.verticalCenter: parent.verticalCenter
                }
                CommonText {
                    text: "Vivant(e) "
                    anchors.verticalCenter: parent.verticalCenter
                }
                CheckBox {
                    id: canGoHomeCheckBox
                    anchors.verticalCenter: parent.verticalCenter
                }
                CommonText {
                    text: "Prêt(e) à sortir "
                    anchors.verticalCenter: parent.verticalCenter
                }
                CheckBox {
                    id: urgenciedCheckBox
                    anchors.verticalCenter: parent.verticalCenter
                }
                CommonText {
                    text: "En soins intensifs"
                    anchors.verticalCenter: parent.verticalCenter
                }
            }
        }

        Rectangle {
            id: bottomArea
            width: 175
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            anchors.bottomMargin: -20
            height: 45; color: "#885F5F5F"
            border.width: 1; border.color: "#424242"
            radius: 6; smooth: true

            Button {
                text: "Valider"
                textInput { font.pixelSize: 14 }
                width: 75
                height: 25
                border.color: "#424242"
                anchors.right: cancelButton.left
                anchors.top: parent.top
                anchors.topMargin: 5
                anchors.rightMargin: 5
                radius: Math.floor(height/2)
                onClicked: finished(true);
            }

            Button {
                id: cancelButton
                text: "Annuler"
                textInput { font.pixelSize: 14 }
                width: 75
                height: 25
                border.color: "#424242"
                anchors.right: parent.right
                anchors.top: parent.top
                anchors.topMargin: 5
                anchors.rightMargin: 10
                radius: Math.floor(height/2)
                onClicked: finished(false);
            }
        }
    }

    RegExpValidator {
        id: regex
        regExp: /[A-Za-z0-9éèàùç\-'_ ]{0,75}/
    }
}
