/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

import QtQuick 1.0
import "../Components"

MouseArea {

    property string title
    signal hideRequest(bool accepted);

    id: popup
    anchors.fill: parent; z: 2
    hoverEnabled: true

    Rectangle {
        anchors.fill: parent
        color: "#000000"
        opacity: 0.7
    }

    ComplexPopup {
        width: 425
        height: 90
        anchors.centerIn: parent
        anchors.verticalCenterOffset: - Math.floor(bottomBar.height/2)
        onHideRequest: popup.hideRequest(false);
        opacity: parent.visible ? 1 : 0
        title: parent.title
        closable: false

        Behavior on opacity { NumberAnimation { duration: 250 } }

        Rectangle {
            id: bottomArea
            width: 175
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottom: parent.bottom
            anchors.bottomMargin: -20
            height: 45; color: "#885F5F5F"
            border.width: 1; border.color: "#424242"
            radius: 6; smooth: true

            Button {
                text: "Valider"
                textInput { font.pixelSize: 14 }
                width: 75
                height: 25
                border.color: "#424242"
                anchors.right: cancelButton.left
                anchors.top: parent.top
                anchors.topMargin: 5
                anchors.rightMargin: 5
                radius: Math.floor(height/2)
                onClicked: popup.hideRequest(true);
            }

            Button {
                id: cancelButton
                text: "Annuler"
                textInput { font.pixelSize: 14 }
                width: 75
                height: 25
                border.color: "#424242"
                anchors.right: parent.right
                anchors.top: parent.top
                anchors.topMargin: 5
                anchors.rightMargin: 10
                radius: Math.floor(height/2)
                onClicked: popup.hideRequest(false);
            }
        }
    }
}
