/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

/*!
    \fn parseJSON(data)
    \brief Retourne un eval() de la chaine de caractère data, de format JSON.
*/

function parseJSON(data) {
    return eval('(' + data + ')');
}

/*!
    \fn unparseJSON(data)
    \brief Retourne une chaine stripslashée depuis une chaine JSON.

    Manipulation inverse de celle de TcpServer::prepareJSON, côté serveur.
*/

function unparseJSON(data) {
    var regExp = new RegExp("\\\\([\\\"\\\\])");
    return String(data).replace(regExp, "$1");
}

/*!
    \fn fillMedicineModel(json)
    \brief Remplit le ListModel medicineModel avec le json passé en argument.
*/

function fillMedicineModel(json) {
    if (json.data) {
        medicineModel.clear();
        for (var i = 0; i < json.data.length; i++) {
            medicineModel.append({
                "name": unparseJSON(json.data[i].name),
                "description": unparseJSON(json.data[i].description),
                "level": unparseJSON(json.data[i].level)
            });
        }
    }
    anchor.requestForBodyPartsModel();
}

/*!
    \fn fillBodyPartsModel(json)
    \brief Remplit le ListModel bodyPartsModel avec le json passé en argument.
*/

function fillBodyPartsModel(json) {
    if (json.data) {
        bodyPartsModel.clear();
        for (var i = 0; i < json.data.length; i++) {
            bodyPartsModel.append({
                "id": json.data[i].id,
                "name": unparseJSON(json.data[i].name)
            });
        }
    }
    if (patientsModel.count > 0) {
        patientCurrentlyViewed = 0;
        anchor.requestForPatient(patientCurrentlyViewed);
    }
}

/*!
    \fn fillPatientsModel(json)
    \brief Remplit le ListModel patientsModel avec le json passé en argument.
*/

function fillPatientsModel(json) {
    if (json.data) {
        var currentDate = new Date();
        patientsModel.clear();
        patientUrgenciedModel.clear();
        for (var i = 0; i < json.data.length; i++) {
            var object = new Object;
            object["name"] = unparseJSON(json.data[i].name);
            object["gender"] = json.data[i].gender;
            object["age"] = parseInt(currentDate.getFullYear()
                - json.data[i].birthyear);
            object["address"] = unparseJSON(json.data[i].adress);
            object["canGoHome"] = json.data[i].canGoHome;
            object["isDead"] = json.data[i].isDead;
            object["urgencied"] = json.data[i].urgencied;
            if (json.data[i].urgencied == 1)
                patientUrgenciedModel.append(object);
            patientsModel.append(object);
        }
    }
    anchor.requestForMedicineModel();
}

/*!
    \fn fillPatientsModel(json)
    \brief Remplit les ListModel patientInfos, patientDiagnostics et
    patientSymptoms avec le json passé en argument.
*/

function fillPatientInfosModel(json) {
    if (json.data) {
        var currentDate = new Date();
        patientDiagnostics.clear();
        patientSymptoms.clear();
        patientPrescriptions.clear();
        patientInfos.set(0, {
            "name": unparseJSON(json.data.name),
            "gender": json.data.gender,
            "age": parseInt(currentDate.getFullYear() - json.data.birthyear),
            "address": unparseJSON(json.data.adress),
            "canGoHome": json.data.canGoHome,
            "isDead": json.data.isDead,
            "urgencied": json.data.urgencied
        });
        if (json.data.diagnostics)
            for (var i = 0; i < json.data.diagnostics.length; i++) {
                var date = new Date();
                date.setTime(json.data.diagnostics[i].date*1000);
                patientDiagnostics.append({
                    "date": Qt.formatDateTime(date, "yyyy-MM-dd hh:mm:ss"),
                    "diagnostic": unparseJSON(
                        json.data.diagnostics[i].diagnostic)
                });
            }
        if (json.data.symptoms)
            for (var i = 0; i < json.data.symptoms.length; i++) {
                var date = new Date();
                date.setTime(json.data.symptoms[i].date*1000);
                patientSymptoms.append({
                    "date": Qt.formatDateTime(date, "yyyy-MM-dd hh:mm:ss"),
                    "symptom": unparseJSON(json.data.symptoms[i].symptom)
                });
            }
        if (json.data.prescriptions)
            for (var i = 0; i < json.data.prescriptions.length; i++) {
                var medicine = medicineModel.get(
                    parseInt(json.data.prescriptions[i].medicine_id));
                var date = new Date();
                date.setTime(json.data.prescriptions[i].date*1000);
                patientPrescriptions.append({
                    "prescription_id": parseInt(
                        json.data.prescriptions[i].prescription_id),
                    "medicine": medicine ? medicine.name : "",
                    "date": Qt.formatDateTime(date, "yyyy-MM-dd à hh:mm:ss"),
                    "medicine_id": parseInt(
                        json.data.prescriptions[i].medicine_id),
                    "duration": unparseJSON(
                        json.data.prescriptions[i].duration)
                });
            }
    }
}

/*!
    \fn fillModelWithNewPatient(json)
    \brief Ajoute des données au ListModel patientsModel avec le json passé en
    argument.
*/

function fillModelWithNewPatient(json) {
    if (json.data) {
        var currentDate = new Date();
        patientsModel.append({
            "name": unparseJSON(json.data.name),
            "gender": json.data.gender,
            "age": parseInt(currentDate.getFullYear() - json.data.birthyear),
            "address": unparseJSON(json.data.adress),
            "canGoHome": json.data.canGoHome,
            "isDead": json.data.isDead
        });
    }
}

/*!
    \fn modifyModelsWithPatient(id, json)
    \brief Modifie les données aux ListModel patientsModel et éventuellement
    patientInfos (si le patient actuellement visionné est le patient \a id)
    avec le json passé en argument.
*/

function modifyModelsWithPatient(id, json) {
    if (patientsModel.count > id && json.data) {
        var currentDate = new Date();
        patientsModel.set(id, {
            "name": unparseJSON(json.data.name),
            "gender": json.data.gender,
            "age": parseInt(currentDate.getFullYear() - json.data.birthyear),
            "address": unparseJSON(json.data.adress),
            "canGoHome": json.data.canGoHome,
            "isDead": json.data.isDead
        });
    }
    if (id == main.patientCurrentlyViewed) {
        patientInfos.set(0, {
            "name": unparseJSON(json.data.name),
            "gender": json.data.gender,
            "age": parseInt(currentDate.getFullYear() - json.data.birthyear),
            "address": unparseJSON(json.data.adress),
            "canGoHome": json.data.canGoHome,
            "isDead": json.data.isDead,
            "urgencied": json.data.urgencied
        });
    }
}

/*!
    \fn modifyOrAddPatient(patientId, name, birthyear, man,
    address, alive, canGoHome, urgencied)
    \brief Engendre la modification ou l'ajout d'un nouveau patient.
*/

function modifyOrAddPatient(patientId, name, birthyear, man,
    address, alive, canGoHome, urgencied) {
    var patient = patientInfos.get(0);

    var currentDate = new Date();
    var _gender = man ? "0" : "1";
    var _age = parseInt(currentDate.getFullYear() - birthyear);
    var _dead = alive ? "0" : "1";
    var _home = canGoHome ? "1" : "0";
    var _urgencied = urgencied ? "1" : "0";
    var list = new Array(name, _age, _gender,
        address, _dead, _home, _urgencied);

    if (patient && patientId != -1) {
        if (patient.name != name || patient.gender != _gender
            || patient.age != _age || patient.address != address
            || patient.canGoHome != _home || patient.isDead != _dead
            || patient.urgencied != _urgencied)
            anchor.modifyPatient(patientId, list);
    }
    else if (patientId == -1)
        anchor.addPatient(list);
}

/*!
    \fn appendNewDiagnostic(json)
    \brief Ajoute une entrée dans la ListModel patientDiagnostics avec le json
    passé en argument.
*/

function appendNewDiagnostic(json) {
    if (json.diagnostic) {
        var date = new Date();
        date.setTime(json.diagnostic.date*1000);
        patientDiagnostics.append({
            "date": Qt.formatDateTime(date, "yyyy-MM-dd hh:mm:ss"),
            "diagnostic": unparseJSON(json.diagnostic.diagnostic)
        });
    }
}

/*!
    \fn appendNewSymptom(json)
    \brief Ajoute une entrée dans la ListModel patientSymptoms avec le json
    passé en argument.
*/

function appendNewSymptom(json) {
    if (json.symptom) {
        var date = new Date();
        date.setTime(json.symptom.date*1000);
        patientSymptoms.append({
            "date": Qt.formatDateTime(date, "yyyy-MM-dd hh:mm:ss"),
            "symptom": unparseJSON(json.symptom.symptom)
        });
    }
}

/*!
    \fn removePrescription(id)
    \brief Retire les entrées à au \a prescription_id \a id dans la ListModel
    patientPrescriptions.
*/

function removePrescription(id) {
    for (var i = 0; i < patientPrescriptions.count; i++) {
        var prescription = patientPrescriptions.get(i);
        if (prescription && prescription.prescription_id == id)
        patientPrescriptions.remove(i);
    }
}

/*!
    \fn appendMessageInChat(username, message)
    \brief Ajoute le \a message envoyé par l'utilisateur \a username dans la
    fenêtre du salon.
*/

function appendMessageInChat(username, message) {
    var currentDate = new Date();
    var date = Qt.formatDateTime(currentDate, "yyyy-MM-dd hh:mm:ss");
    chat.chatTextArea.text += date + " " + (anchor.username == username
        ? "Vous avez " : (username + " a "))
        + "dit :\n" + message + "\n\n";
}

/*!
    \fn appendMessageInChat(username, message)
    \brief Ajoute le \a message envoyé par l'utilisateur \a username dans la
    fenêtre du salon.
*/

function setChatUsers(users) {
    chatUsers.clear();
    for (var i = 0; i < users.length; i++)
        chatUsers.append({"name": users[i]});
}

/*!
    \fn memberEnterOrLeaveEvent(username, enter)
    \brief Envoit une notification d'entrée ou de sortie d'un utilisateur dans
    le salon.
*/

function memberEnterOrLeaveEvent(username, enter) {
    var currentDate = new Date();
    var date = Qt.formatDateTime(currentDate, "yyyy-MM-dd hh:mm:ss");
    chat.chatTextArea.text += "* " + (anchor.username == username
        ? "Vous avez " : (username + " a ")) + (enter ? "rejoint" : "quitté")
        + " le salon (" + date + ").\n\n";
}

/*!
    \fn fillAnalysisModels(json)
    \brief Remplit les ListModel radiosModel et scansModel avec le json passé
    en argument.
*/

function fillAnalysisModels(json) {
    if (json.data) {
        for (var i = 0; i < json.data.radios.length; i++) {
            radiosModel.append({"id": json.data.radios[i].id,
                "customer_id": json.data.radios[i].customer_id,
                "group_id": json.data.radios[i].group_id,
                "x_parts": json.data.radios[i].x_parts,
                "y_parts": json.data.radios[i].y_parts});
        }
        for (var i = 0; i < json.data.scans.length; i++) {
            scansModel.append({"id": json.data.scans[i].id,
                "customer_id": json.data.scans[i].customer_id,
                "group_id": json.data.scans[i].group_id,
                "parts": json.data.scans[i].parts});
        }
    }
}

/*!
    \fn getScans(index, part)
    \brief Fonction utilisée pour récupérer les images d'un scan.
*/

function getScans(index, part) {
    if (part == 0)
        scanPaths.clear();
    var data = scansModel.get(index);
    if (!data || part >= data.parts) {
        analysis.scanModelFilled();
        return;
    }
    anchor.requestForScan(data.id, part);
}

/*!
    \fn receiveScan(id, part, path)
    \brief Remplit le ListModel scanPaths puis appelle getScans() pour
    récupérer la partie suivante.
*/

function receiveScan(id, part, path) {
    scanPaths.append({"id": id, "part": part, "path": path});
    getScans(id, part + 1);
}

/*!
    \fn getRadios(index, x_part, y_part)
    \brief Fonction utilisée pour récupérer les images d'une radio.
*/

function getRadios(index, x_part, y_part) {
    if (x_part == 0 && y_part == 0)
        radioPaths.clear();
    var data = radiosModel.get(index);
    if (!data || (x_part >= data.x_parts)) {
        analysis.radioModelFilled();
        return;
    }
    anchor.requestForRadio(data.id, x_part, y_part);
}

/*!
    \fn receiveRadio(id, x_part, y_part, path)
    \brief Remplit le ListModel radioPaths puis appelle getRadios() pour
    récupérer la partie suivante.
*/

function receiveRadio(id, x_part, y_part, path) {
    radioPaths.append({"id": id, "x_part": x_part, "y_part": y_part, "path": path});
    var data = radiosModel.get(id);

    var max_x = data.x_parts;
    var max_y = data.y_parts;
    var new_x = x_part;
    var new_y = y_part + 1;

    if (new_y >= max_y) {
        new_y = 0;
        new_x++;
    }

    getRadios(id, new_x, new_y);
}
