/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

#ifndef CUSTOMER_H
#define CUSTOMER_H

#include <QtGui>
#include <QtNetwork>

class TcpServer;

class Customer : public QObject
{
    Q_OBJECT

public:
    explicit Customer(QTcpSocket*, TcpServer*);
    ~Customer();
    void send(const QByteArray&);
    QString getPeerAddress();

    /*! Définit le nom de l'utilisateur du client. */
    void setName(const QString &name) {
        _name = name;
    }
    /*! Retourne le nom de l'utilisateur du client. */
    QString getName() const {
        return _name.isEmpty() ? "Unknown" : _name;
    }
    /*! Spécifie si le client est actuellement dans le chat. */
    void setInChat(bool inChat) {
        _inChat = inChat;
    }
    /*! Retourne si le client est actuellement dans le chat. */
    bool inChat() const {
        return _inChat;
    }

private slots:
    void read();
    void logout();

private:
    /*! Le socket du client. */
    QTcpSocket *_socket;
    /*! Le serveur auquel le client est connecté. */
    TcpServer *_server;
    /*! La taille du paquet reçu. */
    quint16 _size;
    /*! Le nom de l'utilisateur du client. */
    QString _name;
    /*! Spécifie si le client est actuellement dans le chat. */
    bool _inChat;
};

#endif // CUSTOMER_H
