/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

#ifndef DATABASE_H
#define DATABASE_H

#include <QtSql>
#include "dbstore.h"
#include "dbstructure.h"

class Database
{
public:
    static Database &getInstance();
    static void freeInstance();
    void initialize();
    const AccountEntry *findAccountByName(QString);
    /*! Contient les entrées de la table account. */
    DBStore<AccountEntry> AccountStore;
    /*! Contient les entrées de la table customer. */
    DBStore<CustomerEntry> CustomerStore;
    /*! Contient les entrées de la table customer_diagnostic. */
    DBStore<CustomerDiagnosticEntry> CustomerDiagnosticStore;
    /*! Contient les entrées de la table customer_prescription. */
    DBStore<CustomerPrescriptionEntry> CustomerPrescriptionStore;
    /*! Contient les entrées de la table customer_symptom. */
    DBStore<CustomerSymptomEntry> CustomerSymptomStore;
    /*! Contient les entrées de la table customer_urgency. */
    DBStore<CustomerUrgencyEntry> CustomerUrgencyStore;
    /*! Contient les entrées de la table group. */
    DBStore<GroupEntry> GroupStore;
    /*! Contient les entrées de la table invoice. */
    DBStore<InvoiceEntry> InvoiceStore;
    /*! Contient les entrées de la table medicine. */
    DBStore<MedicineEntry> MedicineStore;
    /*! Contient les entrées de la table medicine_level. */
    DBStore<MedicineLevelEntry> MedicineLevelStore;
    /*! Contient les entrées de la table radio. */
    DBStore<RadioEntry> RadioStore;
    /*! Contient les entrées de la table scan. */
    DBStore<ScanEntry> ScanStore;
    /*! La base de données. */
    QSqlDatabase *database;

private:
    /*! Constructeur. */
    explicit Database();
    /*! Destructeur. */
    ~Database();
    /*! Pointeur unique. */
    static Database *_instance;
};

/*! Macro vers Database::getInstance(). */
#define db Database::getInstance()

#endif // DATABASE_H
