/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

#include "opcodes.h"
#include "tcpserver.h"

/*!
    \struct OpcodeHandler
    \brief La structure OpcodeHandler permet la gestion des paquets.

    Chaque paquet se différencie des autres par son opcode. Cette structure
    présente donc deux éléments : le nom de l'opcode et un pointeur de fonction
    pointant vers la fonction associée à l'opcode.

    Le tableau \a opcodes définit la fonction associée à chaque opcode.
*/

/*!
    \enum Opcodes
    \brief L'énumération recençant la liste complète des opcodes.
*/

OpcodeHandler opcodes[MSG_MAX_OPCODES] =
{
    { "MSG_PING", &TcpServer::handlePing },
    { "MSG_PONG", &TcpServer::unhandled },
    { "MSG_LOGIN", &TcpServer::handleLogin },
    { "MSG_QUERY_MEDICINE_MODEL", &TcpServer::handleMedicineModel },
    { "MSG_QUERY_PATIENTS_MODEL", &TcpServer::handlePatientsModel },
    { "MSG_QUERY_BODY_PARTS", &TcpServer::handleBodyPartsModel },
    { "MSG_QUERY_PATIENT", &TcpServer::handlePatientQuery },
    { "MSG_NEW_PATIENT", &TcpServer::handleNewPatient },
    { "MSG_MODIFY_PATIENT", &TcpServer::handleModifyPatient },
    { "MSG_NEW_DIAGNOSTIC", &TcpServer::handleNewDiagnostic },
    { "MSG_NEW_SYMPTOM", &TcpServer::handleNewSymptom },
    { "MSG_REMOVE_PRESCRIPTION", &TcpServer::handleRemovePrescription },
    { "MSG_MODIFY_PRESCRIPTION", &TcpServer::handleModifyPrescription },
    { "MSG_NEW_PRESCRIPTION", &TcpServer::handleNewPrescription },
    { "MSG_ENTER_CHAT", &TcpServer::handleEnterChat },
    { "MSG_LEAVE_CHAT", &TcpServer::handleLeaveChat },
    { "MSG_SEND_CHAT_MESSAGE", &TcpServer::handleChatMessage },
    { "MSG_QUERY_CHAT_USERS", &TcpServer::handleChatUsersRequest },
    { "MSG_START_ECG", &TcpServer::handleStartECG },
    { "MSG_STOP_ECG", &TcpServer::handleStopECG },
    { "MSG_ECG_DATA", &TcpServer::unhandled },
    { "MSG_QUERY_ANALYSIS_MODEL", &TcpServer::handleAnalysisModel },
    { "MSG_QUERY_SCAN", &TcpServer::handleScanRequest },
    { "MSG_QUERY_RADIO", &TcpServer::handleRadioRequest }
};
