/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

#ifndef SIMULATOR_H
#define SIMULATOR_H

#include <QtGui>

class Customer;

/*! Intervale entre l'envoi de deux paquets de simulation de données. */
#define UPDATE_INTERVAL 50
/*! Définit le nombre de points disponibles par le simulateur pour l'ECG. */
#define MAX_ECG_POINTS 1000

class Simulator : public QObject
{
    Q_OBJECT
public:
    static Simulator &getInstance();
    static void freeInstance();
    void initialize();
    void addClientWForECG(Customer*);
    void removeClientWForECG(Customer*);

public slots:
    void sendData();

private:
    /*! Constructeur. */
    explicit Simulator();
    /*! Destructeur. */
    ~Simulator();
    /*! Pointeur unique. */
    static Simulator *_instance;
    /*! Timer utilisé pour les actualisations. */
    QTimer *_updateTimer;
    /*! Liste des points utilisés par l'ECG. */
    QList<float> _ecgPoints;
    /*! Liste des clients demandant des données de l'ECG. */
    QList<Customer*> _ecgClients;
    /*! Avancée de chaque client dans l'ECG. */
    QList<int> _ecgProgress;
};

/*! Macro vers Simulator::getInstance(). */
#define simulator Simulator::getInstance()

#endif // SIMULATOR_H
