/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

#ifndef TCPSERVER_H
#define TCPSERVER_H

#include <QtGui>
#include <QtNetwork>

class Customer;

#define CLIENT_USERNAME "developpez.com"
#define CLIENT_PASSWORD "developpez"

class TcpServer : public QTcpServer
{
    Q_OBJECT

public:
    void initialize();
    void handleLogout(Customer*);
    void handleMessage(QDataStream*, Customer*);
    void unhandled(QDataStream*, Customer*);
    void handlePing(QDataStream*, Customer*);
    void handleLogin(QDataStream*, Customer*);
    void handleMedicineModel(QDataStream*, Customer*);
    void handlePatientsModel(QDataStream*, Customer*);
    void handleBodyPartsModel(QDataStream*, Customer*);
    void handlePatientQuery(QDataStream*, Customer*);
    void handleNewPatient(QDataStream*, Customer*);
    void handleModifyPatient(QDataStream*, Customer*);
    void handleNewDiagnostic(QDataStream*, Customer*);
    void handleNewSymptom(QDataStream*, Customer*);
    void handleRemovePrescription(QDataStream*, Customer*);
    void handleModifyPrescription(QDataStream*, Customer*);
    void handleNewPrescription(QDataStream*, Customer*);
    void handleEnterChat(QDataStream*, Customer*);
    void handleLeaveChat(QDataStream*, Customer*);
    void handleChatMessage(QDataStream*, Customer*);
    void handleChatUsersRequest(QDataStream*, Customer*);
    void handleStartECG(QDataStream*, Customer*);
    void handleStopECG(QDataStream*, Customer*);
    void handleAnalysisModel(QDataStream*, Customer*);
    void handleScanRequest(QDataStream*, Customer*);
    void handleRadioRequest(QDataStream*, Customer*);

private slots:
    void handleConnection();

private:
    /*! La liste des clients connectés au serveur. */
    QList<Customer*> _customers;
    QString prepareJSON(const QString &);
    QString preparePatient(const int&);
    void fillStrings(QList<QString> list, ...);
};

#endif // TCPSERVER_H
