/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

#include <QTime>
#include "master.h"
#define LOG_FILE "log.txt"

QFile &logFile()
{
    static QFile file(QCoreApplication::applicationDirPath() + "/" + LOG_FILE);
    return file;
}

void outputHandler(QtMsgType /*type*/, const char *msg)
{
    QString message = QDateTime::currentDateTime()
        .toString("yyyy-MM-dd hh:mm:ss: ") + msg;

    fprintf(stderr, "%s\n", message.toAscii().constData());

    if (logFile().isOpen() || logFile().open(QIODevice::WriteOnly
        | QIODevice::Append | QIODevice::Text))
        logFile().write(QString(message + "\n").toAscii());
}

int main(int argc, char *argv[])
{
    QCoreApplication app(argc, argv);

    logFile().remove();
    qInstallMsgHandler(outputHandler);
    qsrand(QTime::currentTime().secsTo(QTime()));

    new Master;

    return app.exec();
}
