/*
# Copyright (c) 2011 Louis du Verdier
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
*/

#include "master.h"
#include "tcpserver.h"
#include "database.h"
#include "simulator.h"

/*!
    \class Master
    \brief La classe Master est la classe correspondant à la base de
    l'application.

    La classe Master, sert à lancer le TcpServer \a _server puis à
    l'initialiser afin de le lancer. Cela fait, elle initialise la base de
    données ainsi que le simulateur de données.
*/

/*!
    \fn Master::Master()
    \brief Crée et initialise le serveur.
*/

Master::Master() : _server(new TcpServer)
{
    _server->initialize();
    db.initialize();
    simulator.initialize();
}

/*!
    \fn Master::~Master()
    \brief Destructeur de la classe.
*/

Master::~Master()
{
    db.freeInstance();
    simulator.freeInstance();
    _server->close();
    delete _server;
}
